@@ -1,5 +1,5 @@
 package Bot::Cobalt::Core::ContextMeta;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 ## Base class for context-specific dynamic hashes
 ## (ignores, auth, .. )
@@ -26,6 +26,7 @@ sub add {
     AddedAt => time(),
   };
 
+  ## Allow AddedAt to be adjusted:
   if (ref $meta eq 'HASH') {
     $ref->{$_} = $meta->{$_} for keys %$meta;
   }
@@ -37,7 +38,9 @@ sub add {
 
 sub clear {
   my ($self, $context) = @_;
+
   $self->_list({}) unless defined $context;
+
   delete $self->_list->{$context}  
 }
 
@@ -59,11 +62,13 @@ sub fetch {
     unless defined $context and defined $key;
 
   return unless exists $self->_list->{$context};
+
   return $self->_list->{$context}->{$key}  
 }
 
 sub list {
   my $self = shift;
+
   wantarray ? $self->list_as_array(@_) : $self->list_as_ref(@_)
 }
 
@@ -71,13 +76,15 @@ sub list {
 
 sub list_as_array {
   my $self = shift;
+
   my $listref = $self->list_as_ref(@_);
+
   keys %$listref
 }
 
 sub list_as_ref {
   my ($self, $context) = @_;
-  $context ? $self->_list->{$context} : $self->_list ;
+  defined $context ? $self->_list->{$context} : $self->_list ;
 }
 
 1;
