@@ -1,5 +1,5 @@
 package Bot::Cobalt::Frontend::RC;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use strictures 1;
 
@@ -25,7 +25,7 @@ sub rc_read {
   my $generic_crappy_err = sub {
     warn(
       "Errors reported during rcfile parse\n",
-      "You may have an old, incompatible rcfile.\n",
+      "You may have an old, incompatible, or broken rcfile.\n",
       "Path: $rcfile\n",
       "Try running cobalt2-installer\n"
     );
@@ -82,7 +82,7 @@ sub rc_write {
   }
 }
 
-1
+1;
 __END__
 
 =pod
