@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Extras::Shorten;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use 5.10.1;
 use strict;
@@ -11,7 +11,7 @@ use Object::Pluggable::Constants qw/ :ALL /;
 use HTTP::Request;
 use URI::Escape;
 
-sub new { bless {}, shift }
+sub new { bless [], shift }
 
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
