@@ -1,13 +1,13 @@
 package Bot::Cobalt::Plugin::Games::Magic8;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use 5.10.1;
 use strict;
 use warnings;
 
-our @responses;
+my @responses;
 
-sub new { bless {}, shift }
+sub new { bless [], shift }
 
 sub execute {
   my ($self, $msg) = @_;
