@@ -1,11 +1,11 @@
 package Bot::Cobalt::Plugin::Games::RockPaperScissors;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use 5.10.1;
 use strict;
 use warnings;
 
-sub new { bless {}, shift }
+sub new { bless [], shift }
 
 sub execute {
   my ($self, $msg, $rps) = @_;
@@ -18,8 +18,8 @@ sub execute {
 
   my $beats = {
     scissors => 'paper',
-    paper => 'rock',
-    rock => 'scissors',
+    paper    => 'rock',
+    rock     => 'scissors',
   };
 
   my $throw = (keys %$beats)[rand(keys %$beats)];
