@@ -1,21 +1,19 @@
 package Bot::Cobalt::Plugin::OutputFilters::StripColor;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
-use 5.10.1;
-use strict;
-use warnings;
+use strictures 1;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
 use IRC::Utils qw/ strip_color /;
 
-sub new { bless {}, shift }
+sub new { bless [], shift }
 
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
 
   $core->plugin_register( $self, 'USER',
-    [ 'message', 'notice', 'ctcp' ],
+    'message', 'notice', 'ctcp',
   );
 
   $core->log->info("Registered, filtering COLORS");
@@ -25,13 +23,17 @@ sub Cobalt_register {
 
 sub Cobalt_unregister {
   my ($self, $core) = splice @_, 0, 2;
+
   $core->log->info("Unregistered");
+
   return PLUGIN_EAT_NONE
 }
 
 sub Outgoing_message {
   my ($self, $core) = splice @_, 0, 2;
+
   ${$_[2]} = strip_color(${$_[2]});
+
   return PLUGIN_EAT_NONE
 }
 
@@ -40,8 +42,11 @@ sub Outgoing_notice { Outgoing_message(@_) }
 sub Outgoing_ctcp {
   my ($self, $core) = splice @_, 0, 2;
   my $type = ${$_[1]};
+
   return PLUGIN_EAT_NONE unless uc($type) eq 'ACTION';
+
   ${$_[3]} = strip_color(${$_[3]});
+
   return PLUGIN_EAT_NONE
 }
 
